==> core-react-0.8.0.tgz: package/es/dialog/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import ReactDOM from 'react-dom';
import marked from 'marked';
import * as type from '../_utils/type';
import Dialog from './Dialog';
import DialogBody from './DialogBody';
import DialogButtons from './DialogButtons';
import DialogHeader from './DialogHeader';

var ClassicDialog = /*#__PURE__*/function (_React$Component) {
  _inherits(ClassicDialog, _React$Component);

  function ClassicDialog() {
    var _this;

    _classCallCheck(this, ClassicDialog);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ClassicDialog).call(this));

    _defineProperty(_assertThisInitialized(_this), "handleDialogClose", function () {
      var _this$props, _this$props$onClose;

      _this.setState({
        isOpen: false
      });

      (_this$props = _this.props) === null || _this$props === void 0 ? void 0 : (_this$props$onClose = _this$props.onClose) === null || _this$props$onClose === void 0 ? void 0 : _this$props$onClose.call(_this$props);
    });

    _this.state = {
      isOpen: true
    };
    return _this;
  }

  _createClass(ClassicDialog, [{
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          backdrop = _this$props2.backdrop,
          lock = _this$props2.lock,
          type = _this$props2.type,
          options = _this$props2.options,
          acceptLabel = _this$props2.acceptLabel,
          message = _this$props2.message,
          cancelLabel = _this$props2.cancelLabel;
      return React.createElement("div", null, !!this.state.isOpen && React.createElement(Dialog, {
        type: "dialog",
        onClose: this.handleDialogClose,
        backdrop: backdrop,
        lock: lock
      }, React.createElement(DialogHeader, {
        type: type,
        icon: options === null || options === void 0 ? void 0 : options.icon
      }), React.createElement(DialogBody, null, React.createElement("div", {
        className: "".concat("waui", "-dialog__body-markdown"),
        dangerouslySetInnerHTML: {
          __html: marked(message)
        }
      })), React.createElement(DialogButtons, _extends({
        type: type,
        acceptLabel: acceptLabel,
        cancelLabel: cancelLabel
      }, options))));
    }
  }]);

  return ClassicDialog;
}(React.Component);

var _render = function render(props) {
  var isOpen = false;
  var messageQueue = [];

  var handleClose = function handleClose() {
    isOpen = false;
    var head = messageQueue[0] && messageQueue.shift();
    head && _render(head);
  };

  _render = function render(nextProps) {
    props = Object.assign({}, props, nextProps, {
      onClose: handleClose
    });

    if (isOpen) {
      return messageQueue.push(props);
    }

    isOpen = true;
    var container = document.createElement('div');
    ReactDOM.render(React.createElement(ClassicDialog, props), container);
  };

  _render();
};

var getDialogParams = function getDialogParams(args) {
  var stringArray = [];
  var options = {};
  Array.from(args).forEach(function (v) {
    type.isString(v) && stringArray.push(v);
    type.isObject(v) && Object.assign(options, v);
  });
  return {
    message: stringArray[0] || 'Dialog message must be provided.',
    acceptLabel: stringArray[1] || 'OK',
    cancelLabel: stringArray[2] || 'CANCEL',
    options: options
  };
};

var dialog = {
  confirm: function confirm() {
    var _getDialogParams = getDialogParams(arguments),
        message = _getDialogParams.message,
        acceptLabel = _getDialogParams.acceptLabel,
        cancelLabel = _getDialogParams.cancelLabel,
        options = _getDialogParams.options;

    _render({
      message: message,
      acceptLabel: acceptLabel,
      cancelLabel: cancelLabel,
      options: options,
      type: 'confirm',
      backdrop: true,
      lock: true,
      open: true
    });
  },
  accept: function accept() {
    var _getDialogParams2 = getDialogParams(arguments),
        message = _getDialogParams2.message,
        acceptLabel = _getDialogParams2.acceptLabel,
        cancelLabel = _getDialogParams2.cancelLabel,
        options = _getDialogParams2.options;

    _render({
      message: message,
      acceptLabel: acceptLabel,
      cancelLabel: cancelLabel,
      options: options,
      type: 'accept',
      backdrop: true,
      lock: true,
      open: true
    });
  },
  warning: function warning() {
    var _getDialogParams3 = getDialogParams(arguments),
        message = _getDialogParams3.message,
        acceptLabel = _getDialogParams3.acceptLabel,
        cancelLabel = _getDialogParams3.cancelLabel,
        options = _getDialogParams3.options;

    _render({
      message: message,
      acceptLabel: acceptLabel,
      cancelLabel: cancelLabel,
      options: options,
      type: 'warning',
      backdrop: true,
      lock: true,
      open: true
    });
  },
  danger: function danger() {
    var _getDialogParams4 = getDialogParams(arguments),
        message = _getDialogParams4.message,
        acceptLabel = _getDialogParams4.acceptLabel,
        cancelLabel = _getDialogParams4.cancelLabel,
        options = _getDialogParams4.options;

    _render({
      message: message,
      acceptLabel: acceptLabel,
      cancelLabel: cancelLabel,
      options: options,
      type: 'danger',
      backdrop: true,
      lock: true,
      open: true
    });
  },
  close: function close() {
    _render({
      open: false
    });
  }
};
export default dialog;

==> core-react-0.8.2.tgz: package/es/dialog/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import ReactDOM from 'react-dom';
import marked from 'marked';
import * as type from '../_utils/type';
import Dialog from './Dialog';
import DialogBody from './DialogBody';
import DialogButtons from './DialogButtons';
import DialogHeader from './DialogHeader';

var ClassicDialog = /*#__PURE__*/function (_React$Component) {
  _inherits(ClassicDialog, _React$Component);

  function ClassicDialog() {
    var _this;

    _classCallCheck(this, ClassicDialog);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ClassicDialog).call(this));

    _defineProperty(_assertThisInitialized(_this), "handleDialogClose", function () {
      var _this$props, _this$props$onClose;

      _this.setState({
        isOpen: false
      });

      (_this$props = _this.props) === null || _this$props === void 0 ? void 0 : (_this$props$onClose = _this$props.onClose) === null || _this$props$onClose === void 0 ? void 0 : _this$props$onClose.call(_this$props);
    });

    _this.state = {
      isOpen: true
    };
    return _this;
  }

  _createClass(ClassicDialog, [{
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          backdrop = _this$props2.backdrop,
          lock = _this$props2.lock,
          type = _this$props2.type,
          options = _this$props2.options,
          acceptLabel = _this$props2.acceptLabel,
          message = _this$props2.message,
          cancelLabel = _this$props2.cancelLabel;
      return (/*#__PURE__*/React.createElement("div", null, !!this.state.isOpen && /*#__PURE__*/React.createElement(Dialog, {
          type: "dialog",
          onClose: this.handleDialogClose,
          backdrop: backdrop,
          lock: lock
        }, /*#__PURE__*/React.createElement(DialogHeader, {
          type: type,
          icon: options === null || options === void 0 ? void 0 : options.icon
        }), /*#__PURE__*/React.createElement(DialogBody, null, /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-dialog__body-markdown"),
          dangerouslySetInnerHTML: {
            __html: marked(message)
          }
        })), /*#__PURE__*/React.createElement(DialogButtons, _extends({
          type: type,
          acceptLabel: acceptLabel,
          cancelLabel: cancelLabel
        }, options))))
      );
    }
  }]);

  return ClassicDialog;
}(React.Component);

var _render = function render(props) {
  var isOpen = false;
  var messageQueue = [];

  var handleClose = function handleClose() {
    isOpen = false;
    var head = messageQueue[0] && messageQueue.shift();
    head && _render(head);
  };

  _render = function render(nextProps) {
    props = Object.assign({}, props, nextProps, {
      onClose: handleClose
    });

    if (isOpen) {
      return messageQueue.push(props);
    }

    isOpen = true;
    var container = document.createElement('div');
    ReactDOM.render( /*#__PURE__*/React.createElement(ClassicDialog, props), container);
  };

  _render();
};

var getDialogParams = function getDialogParams(args) {
  var stringArray = [];
  var options = {};
  Array.from(args).forEach(function (v) {
    type.isString(v) && stringArray.push(v);
    type.isObject(v) && Object.assign(options, v);
  });
  return {
    message: stringArray[0] || 'Dialog message must be provided.',
    acceptLabel: stringArray[1] || 'OK',
    cancelLabel: stringArray[2] || 'CANCEL',
    options: options
  };
};

var dialog = {
  confirm: function confirm() {
    var _getDialogParams = getDialogParams(arguments),
        message = _getDialogParams.message,
        acceptLabel = _getDialogParams.acceptLabel,
        cancelLabel = _getDialogParams.cancelLabel,
        options = _getDialogParams.options;

    _render({
      message: message,
      acceptLabel: acceptLabel,
      cancelLabel: cancelLabel,
      options: options,
      type: 'confirm',
      backdrop: true,
      lock: true,
      open: true
    });
  },
  accept: function accept() {
    var _getDialogParams2 = getDialogParams(arguments),
        message = _getDialogParams2.message,
        acceptLabel = _getDialogParams2.acceptLabel,
        cancelLabel = _getDialogParams2.cancelLabel,
        options = _getDialogParams2.options;

    _render({
      message: message,
      acceptLabel: acceptLabel,
      cancelLabel: cancelLabel,
      options: options,
      type: 'accept',
      backdrop: true,
      lock: true,
      open: true
    });
  },
  warning: function warning() {
    var _getDialogParams3 = getDialogParams(arguments),
        message = _getDialogParams3.message,
        acceptLabel = _getDialogParams3.acceptLabel,
        cancelLabel = _getDialogParams3.cancelLabel,
        options = _getDialogParams3.options;

    _render({
      message: message,
      acceptLabel: acceptLabel,
      cancelLabel: cancelLabel,
      options: options,
      type: 'warning',
      backdrop: true,
      lock: true,
      open: true
    });
  },
  danger: function danger() {
    var _getDialogParams4 = getDialogParams(arguments),
        message = _getDialogParams4.message,
        acceptLabel = _getDialogParams4.acceptLabel,
        cancelLabel = _getDialogParams4.cancelLabel,
        options = _getDialogParams4.options;

    _render({
      message: message,
      acceptLabel: acceptLabel,
      cancelLabel: cancelLabel,
      options: options,
      type: 'danger',
      backdrop: true,
      lock: true,
      open: true
    });
  },
  close: function close() {
    _render({
      open: false
    });
  }
};
export default dialog;
